@@ -1,12 +1,10 @@
-import asyncio
-import ipaddress
+import copy
 import os
 import unittest
 import unittest.mock as mock
 import warnings
 from typing import Literal
 
-import pkg_resources
 import pytest
 import pytest_asyncio
 import requests
@@ -37,18 +35,6 @@ os.environ["GRADIO_ANALYTICS_ENABLED"] = "False"
 
 
 class TestUtils(unittest.TestCase):
-    @mock.patch("pkg_resources.require")
-    def test_should_fail_with_distribution_not_found(self, mock_require):
-        mock_require.side_effect = pkg_resources.DistributionNotFound()
-
-        with warnings.catch_warnings(record=True) as w:
-            warnings.simplefilter("always")
-            version_check()
-            self.assertEqual(
-                str(w[-1].message),
-                "gradio is not setup or installed properly. Unable to get version info.",
-            )
-
     @mock.patch("requests.get")
     def test_should_warn_with_unable_to_parse(self, mock_get):
         mock_get.side_effect = json.decoder.JSONDecodeError("Expecting value", "", 0)
@@ -144,6 +130,81 @@ class TestAssertConfigsEquivalent(unittest.TestCase):
                 XRAY_CONFIG_WITH_MISTAKE, XRAY_CONFIG
             )
 
+    def test_different_dependencies(self):
+        config1 = {
+            "version": "3.0.20\n",
+            "mode": "blocks",
+            "dev_mode": True,
+            "components": [
+                {
+                    "id": 1,
+                    "type": "textbox",
+                    "props": {
+                        "lines": 1,
+                        "max_lines": 20,
+                        "placeholder": "What is your name?",
+                        "value": "",
+                        "show_label": True,
+                        "name": "textbox",
+                        "visible": True,
+                        "style": {},
+                    },
+                },
+                {
+                    "id": 2,
+                    "type": "textbox",
+                    "props": {
+                        "lines": 1,
+                        "max_lines": 20,
+                        "value": "",
+                        "show_label": True,
+                        "name": "textbox",
+                        "visible": True,
+                        "style": {},
+                    },
+                },
+                {
+                    "id": 3,
+                    "type": "image",
+                    "props": {
+                        "image_mode": "RGB",
+                        "source": "upload",
+                        "tool": "editor",
+                        "streaming": False,
+                        "show_label": True,
+                        "name": "image",
+                        "visible": True,
+                        "style": {"height": 54, "width": 240},
+                    },
+                },
+            ],
+            "theme": "default",
+            "css": None,
+            "enable_queue": False,
+            "layout": {"id": 0, "children": [{"id": 1}, {"id": 2}, {"id": 3}]},
+            "dependencies": [
+                {
+                    "targets": [1],
+                    "trigger": "submit",
+                    "inputs": [1],
+                    "outputs": [2],
+                    "backend_fn": True,
+                    "js": None,
+                    "status_tracker": None,
+                    "queue": None,
+                    "api_name": "greet",
+                    "scroll_to_output": False,
+                    "show_progress": True,
+                    "documentation": [["(str): text"], ["(str | None): text"]],
+                }
+            ],
+        }
+
+        config2 = copy.deepcopy(config1)
+        config2["dependencies"][0]["documentation"] = None
+        with self.assertRaises(AssertionError):
+            assert_configs_are_equivalent_besides_ids(config1, config2)
+
 
 class TestFormatNERList(unittest.TestCase):
     def test_format_ner_list_standard(self):
@@ -200,7 +261,7 @@ async def client():
 class TestRequest:
     @pytest.mark.asyncio
     async def test_get(self):
-        client_response = await Request(
+        client_response: Request = await Request(
             method=Request.Method.GET,
             url="http://headers.jsontest.com/",
         )
@@ -210,7 +271,7 @@ class TestRequest:
 
     @pytest.mark.asyncio
     async def test_post(self):
-        client_response = await Request(
+        client_response: Request = await Request(
             method=Request.Method.POST,
             url="https://reqres.in/api/users",
             json={"name": "morpheus", "job": "leader"},
@@ -228,7 +289,7 @@ class TestRequest:
             id: str
             createdAt: str
 
-        client_response = await Request(
+        client_response: Request = await Request(
             method=Request.Method.POST,
             url="https://reqres.in/api/users",
             json={"name": "morpheus", "job": "leader"},
@@ -242,7 +303,7 @@ class TestRequest:
             name: Literal[str] = "John"
             job: str
 
-        client_response = await Request(
+        client_response: Request = await Request(
             method=Request.Method.POST,
             url="https://reqres.in/api/users",
             json={"name": "morpheus", "job": "leader"},
@@ -261,7 +322,7 @@ class TestRequest:
 
         validate_response_data.side_effect = Exception()
 
-        client_response = await Request(
+        client_response: Request = await Request(
             method=Request.Method.GET,
             url="https://reqres.in/api/users",
             exception_type=ResponseValidationException,
@@ -275,7 +336,7 @@ class TestRequest:
                 return response
             raise Exception
 
-        client_response = await Request(
+        client_response: Request = await Request(
             method=Request.Method.POST,
             url="https://reqres.in/api/users",
             json={"name": "morpheus", "job": "leader"},
@@ -294,7 +355,7 @@ class TestRequest:
                     return response
             raise Exception
 
-        client_response = await Request(
+        client_response: Request = await Request(
             method=Request.Method.POST,
             url="https://reqres.in/api/users",
             json={"name": "morpheus", "job": "leader"},
